@@ -8,25 +8,23 @@ my @profiles =  ();
 
 #FIX: Do this after script is compiled. Look for some hook...
 sub trace_load {
-	my( $self ) =  shift;
-
-	if( $_[0] eq "*main::_<$0" ) { #<-- This is tricky
+	if( $_[1] eq "*main::_<$0" ) { #<-- This is tricky
 		while( my( $key, $value ) =  each %$actions ) {
 			#TODO: call process here
 			$DB::commands->{ a }->( "$key $value" );
 		}
 	}
-
-	return $self->SUPER::trace_load( @_ );
 }
 
 
 
-BEGIN{
-	$DB::options{ trace_load } =  1;
-	push @ISA, 'Devel::DebugHooks';
-}
 use Devel::DebugHooks();
+BEGIN{
+	push @ISA, 'Devel::DebugHooks';
+	my $handler =  DB::reg( 'trace_load', 'kill_print' );
+	$$handler->{ context } =  $DB::dbg;
+	$$handler->{ code }    =  $DB::dbg->can( 'trace_load' );
+}
 use Filter::Util::Call;
 
 
@@ -70,5 +68,6 @@ sub filter {
 }
 
 
+sub Devel::DebugHooks::Commands::interact { 0 }
 
 1;
